/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: Pops, TCSDeveloper
 */

using System;

namespace TopCoder.Rules.DependencyMap.View
{

    /// <summary>
    /// This interface defines the contract that implementors of a diagram renderer should follow. A DiagramRenderer
    /// implementation will provide a method that will supply the component a IGraphics implementation that will be
    /// used to 'paint' the diagram with. The implementation will then also provide a 'disposing' method to signal
    /// when the IGraphics is no longer needed and should be disposed of (giving the implementor the chance to write
    /// out a file or to otherwise take care of external resources).
    /// </summary>
    public interface IDiagramRenderer
    {

        /// <summary>
        /// This method will be called by the DependencyRenderer to retreive a IGraphics object to paint the
        /// diagram with. The dependency is passed with this call to allow the renderer implementation to configure
        /// itself (maybe configuring a file name based on the dependency being rendered).
        /// </summary>
        /// <param name="dependency">The dependency that will be rendered</param>
        /// <returns>A IGraphics object that can be used to paint the diagram with</returns>
        /// <exception cref="ArgumentNullException">if dependency is null</exception>
        /// <exception cref="RendererException">if an error occurs getting the graphics</exception>
        IGraphics GetGraphics(Dependency dependency);

    }

}
